@@ -1,6 +1,6 @@
 use crate::internal_prelude::*;
 
-#[derive(Clone)]
+#[derive(Clone, Debug, Eq, Ord, PartialEq, PartialOrd, Hash)]
 pub struct DirectSource(pub(crate) Handle);
 
 impl DirectSource {
@@ -11,6 +11,7 @@ impl DirectSource {
                 syz_createDirectSource(
                     &mut h as *mut syz_Handle,
                     context.to_syz_handle(),
+                    null_mut(),
                     ud,
                     Some(cb),
                 )
